<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\127\x6f\x72\x64\120\x72\145\x73\x73"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\157\x64\145\152\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\x53\164\141\164\x69\x63"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\171\x74\150\157\156"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\x52\x65\x76\x65\162\163\x65\x50\x72\157\170\x79"; private const VARNISH_CACHE_SERVER = "\61\x32\x37\x2e\60\56\60\x2e\61\x3a\x36\60\70\61"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\106\x53\x5f\115\x45\124\x48\x4f\104" => ["\x76\141\154\165\145" => "\x64\151\x72\x65\x63\x74", "\x72\141\167" => false], "\127\x50\x5f\104\x45\102\125\x47\x5f\104\x49\123\120\x4c\x41\131" => ["\x76\141\x6c\x75\x65" => "\146\x61\x6c\163\145", "\162\141\x77" => true], "\x57\120\x5f\104\x45\102\x55\x47\x5f\114\x4f\107" => ["\x76\x61\x6c\165\x65" => "\164\162\x75\145", "\x72\141\167" => true], "\103\x4f\116\103\101\124\105\x4e\101\124\x45\137\123\x43\x52\x49\120\124\x53" => ["\166\x61\154\x75\x65" => "\146\x61\x6c\x73\145", "\x72\141\167" => true], "\x41\125\124\117\x53\101\126\x45\137\x49\x4e\124\105\x52\126\101\x4c" => ["\x76\x61\x6c\x75\x65" => 600, "\162\141\x77" => true], "\x57\120\137\120\x4f\x53\124\x5f\122\105\126\x49\123\x49\x4f\x4e\123" => ["\166\x61\x6c\x75\x65" => 5, "\162\x61\x77" => true], "\x45\115\120\124\x59\137\x54\x52\101\x53\110\x5f\104\101\x59\x53" => ["\166\141\154\x75\x65" => 21, "\x72\141\167" => true]]; private array $wordPressMultiSiteConfigValues = ["\x57\120\x5f\x41\x4c\114\117\x57\x5f\115\x55\114\x54\x49\123\x49\x54\x45" => ["\x76\x61\154\x75\145" => "\164\x72\165\x65", "\162\141\167" => true], "\115\125\x4c\x54\x49\x53\111\x54\105" => ["\x76\141\x6c\x75\x65" => "\x74\x72\165\x65", "\x72\x61\x77" => true], "\123\125\102\x44\117\115\101\111\116\137\x49\x4e\123\x54\101\114\114" => ["\166\141\154\165\145" => "\146\141\x6c\163\145", "\x72\x61\167" => true], "\x44\117\115\x41\x49\116\x5f\x43\125\122\x52\x45\x4e\x54\x5f\x53\111\124\105" => ["\x76\x61\154\165\145" => '', "\162\141\167" => false], "\120\x41\124\110\137\103\x55\x52\122\105\116\x54\137\123\111\x54\x45" => ["\x76\x61\x6c\165\145" => "\x2f", "\x72\x61\x77" => false], "\x53\111\124\105\137\x49\104\x5f\103\x55\x52\122\105\x4e\124\137\x53\x49\124\x45" => ["\166\x61\154\165\x65" => 1, "\x72\x61\x77" => true], "\102\114\x4f\x47\137\x49\x44\137\x43\125\122\x52\105\x4e\124\x5f\x53\111\124\105" => ["\x76\141\154\165\x65" => 1, "\x72\141\167" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto de553; D8587: $this->databaseServerEntityManager = $databaseServerEntityManager; goto f7d54; Edc23: $this->databaseEntityManager = $databaseEntityManager; goto d2679; f2710: $this->domainNameParser = $domainNameParser; goto e0867; de553: $this->configManager = $configManager; goto D7450; e0867: $this->validator = $validator; goto A3da9; d2679: $this->databaseUserEntityManager = $databaseUserEntityManager; goto D8587; f7d54: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto f2710; A3da9: parent::__construct($translator, $logger); goto Cb473; D7450: $this->siteEntityManager = $siteEntityManager; goto Faff7; Faff7: $this->certificateEntityManager = $certificateEntityManager; goto Edc23; Cb473: } public function index(Request $request) : Response { goto Cd55b; c707b: return $response; goto D3626; F969a: E9338: goto F6c54; Fb87f: a3822: goto c707b; E4019: $response = $this->render("\106\162\157\156\x74\x65\x6e\144\x2f\x53\x69\x74\145\57\116\145\x77\x2f\151\x6e\x64\x65\x78\56\x68\x74\155\154\x2e\164\x77\151\x67", ["\165\163\x65\x72" => $user]); goto Fb87f; F0bf5: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\163\151\164\x65\x73")); goto ba0d1; F6c54: $user = $this->getUser(); goto E4019; Cd55b: $hasPermissions = $this->hasPermissions(); goto C1b67; C1b67: if (true === $hasPermissions) { goto E9338; } goto F0bf5; ba0d1: goto a3822; goto F969a; D3626: } public function newPythonSite(Request $request) : Response { goto Bacb4; A493c: $response = $this->render("\106\162\x6f\x6e\164\145\x6e\144\57\x53\151\164\x65\57\116\x65\167\x2f\x70\x79\164\x68\157\156\56\150\164\x6d\154\56\x74\x77\151\x67", ["\165\163\145\162" => $user, "\146\157\x72\x6d" => $form->createView(), "\x66\x6f\x72\155\x45\162\162\157\162\x73" => $this->formErrors]); goto e24c6; d1d2b: if (!(true === $form->isSubmitted())) { goto a5c97; } goto F750a; A8099: goto c0ef0; goto Ddc00; Eed87: if (true === $hasPermissions) { goto e7be8; } goto cbb04; Bacb4: $hasPermissions = $this->hasPermissions(); goto Eed87; e24c6: c0ef0: goto d093f; Ef949: $user = $this->getUser(); goto f9d9e; B87ef: $form = $this->createPythonSiteForm($pythonSettings); goto e6568; d159a: ed170: goto A493c; cbb04: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\x69\164\x65\163")); goto A8099; e6568: if (!(true === $request->isMethod("\x50\117\123\124"))) { goto ed170; } goto d7ecb; d093f: return $response; goto c3db8; d7ecb: $form->handleRequest($request); goto d1d2b; a5237: if (!(false === is_null($response))) { goto D496c; } goto Ea028; Ea028: return $response; goto C27a3; C27a3: D496c: goto Ba265; F750a: $response = $this->handleCreatePythonSiteForm($request, $form); goto a5237; Ba265: a5c97: goto d159a; Ddc00: e7be8: goto Ef949; f9d9e: $pythonSettings = new PythonSettingsEntity(); goto B87ef; c3db8: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto e36c4; c2fd3: return $form; goto Baa9a; e36c4: $form = $this->createForm("\x41\x70\160\134\106\157\x72\155\x5c\123\151\164\145\x4e\145\x77\120\171\x74\150\x6f\x6e\x54\171\x70\x65", $pythonSettings, ["\141\x63\x74\x69\x6f\156" => $this->generateUrl("\x63\154\160\137\163\151\x74\145\137\160\x79\x74\150\157\x6e\x5f\x6e\x65\167"), "\155\145\x74\x68\x6f\x64" => "\x50\117\123\x54", "\x61\x74\164\162" => ["\x69\144" => "\156\145\x77\x2d\x70\171\x74\150\157\x6e\55\163\151\164\145\x2d\x66\157\162\155"]]); goto C16c4; C16c4: $form->add("\x73\165\142\155\x69\164", SubmitType::class, ["\141\x74\164\x72" => ["\x63\154\141\163\163" => "\x62\x74\x6e\x20\142\164\156\x2d\x6c\x67\x20\x62\164\156\x2d\x62\x6c\x75\x65"], "\154\141\142\x65\154" => "\103\x72\x65\141\x74\145"]); goto c2fd3; Baa9a: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto C43e6; a9970: goto aa81b; goto F9027; dcd26: try { goto c4d52; B453e: throw new \Exception(sprintf("\x56\x68\157\x73\164\x20\x74\x65\155\x70\154\x61\164\x65\x20\42\45\163\x22\x20\x6e\157\x74\x20\x66\157\165\x6e\x64\x2e", $vhostTemplateName)); goto E3ab3; Eb74e: $port = $form->get("\160\157\162\164")->getData(); goto C4ef9; C4459: $pythonVersion = $form->get("\x70\x79\x74\150\157\156\126\145\x72\163\151\x6f\x6e")->getData(); goto Eb74e; e3331: $user = $this->getUser(); goto f3c6f; c4d52: $session = $request->getSession(); goto Ca2ff; f3c6f: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto c2a33; bf575: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\x73\151\164\x65\x73")); goto e0331; C8251: $siteUserPassword = $form->get("\163\151\164\145\x55\x73\x65\162\x50\x61\x73\x73\x77\157\162\x64")->getData(); goto B1946; C4ef9: $siteUser = $form->get("\x73\151\164\x65\x55\163\145\162")->getData(); goto C8251; ce6ce: aea06: goto e3331; eeb4a: if (false === is_null($vhostTemplateEntity)) { goto aea06; } goto B453e; bfd87: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto E04f0; C14f2: B3000: goto f94c3; c2a33: $eventData = ["\163\x69\164\x65" => $domainName, "\163\x69\164\145\125\x73\145\x72" => $siteUser, "\x70\171\164\x68\x6f\156\126\145\x72\163\x69\157\x6e" => $pythonVersion, "\160\x6f\162\x74" => $port]; goto bfd87; B1946: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto db8d4; e0331: return $response; goto C14f2; E04f0: $session->getFlashBag()->set("\163\165\143\143\145\x73\x73", $this->translator->trans("\123\x69\x74\145\40\150\141\x73\x20\142\x65\145\x6e\x20\x63\162\x65\141\164\145\x64\56")); goto bf575; Ca2ff: $domainName = $form->get("\144\x6f\155\141\x69\x6e\116\x61\155\145")->getData(); goto C4459; E3ab3: goto B3000; goto ce6ce; db8d4: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto eeb4a; f94c3: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\147\x65\x72", $this->translator->trans("\x41\x6e\40\x65\162\x72\157\162\x20\x68\x61\163\40\157\143\x63\x75\162\162\145\144\54\x20\145\x72\x72\157\162\40\155\x65\x73\x73\141\x67\145\72\x20\45\145\x72\162\x6f\x72\x4d\145\x73\x73\x61\147\145\45", ["\x25\x65\x72\162\157\162\115\145\163\163\x61\x67\145\45" => $e->getMessage()])); } goto Ff8de; Ff8de: aa81b: goto Adbcb; d7f60: $this->formErrors = $this->getErrorMessages($form); goto a9970; F9027: fd7f2: goto dcd26; C43e6: if (true === $form->isValid()) { goto fd7f2; } goto d7f60; Adbcb: } public function newReverseProxy(Request $request) : Response { goto fa5ed; A1d79: if (true === $hasPermissions) { goto f1c21; } goto f4571; f33f5: D6518: goto e2771; F03cf: $form->handleRequest($request); goto B530e; e5895: $response = $this->render("\106\162\x6f\x6e\164\x65\156\x64\x2f\123\x69\x74\145\57\x4e\x65\x77\57\x72\145\166\145\x72\163\x65\x2d\x70\x72\x6f\x78\x79\56\150\164\x6d\x6c\x2e\164\167\151\147", ["\165\163\x65\162" => $user, "\x66\157\162\155" => $form->createView(), "\x66\157\x72\155\105\162\162\157\162\x73" => $this->formErrors]); goto f33f5; ac158: if (!(false === is_null($response))) { goto A7cbb; } goto Aa6c6; F49e7: if (!(true === $request->isMethod("\120\x4f\123\124"))) { goto D27de; } goto F03cf; B7124: D27de: goto e5895; B530e: if (!(true === $form->isSubmitted())) { goto ac367; } goto fc57b; f7229: A7cbb: goto c7d88; d30f2: $form = $this->createReverseProxyForm(); goto F49e7; ecaee: $user = $this->getUser(); goto d30f2; c7d88: ac367: goto B7124; f5722: f1c21: goto ecaee; Fe2ce: goto D6518; goto f5722; fc57b: $response = $this->handleReverseProxyForm($request, $form); goto ac158; f4571: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\163\151\x74\145\x73")); goto Fe2ce; Aa6c6: return $response; goto f7229; e2771: return $response; goto F3d6f; fa5ed: $hasPermissions = $this->hasPermissions(); goto A1d79; F3d6f: } private function createReverseProxyForm() : Form { goto C8eb3; fcd6a: return $form; goto a4d73; D8981: $form->add("\x73\165\142\x6d\x69\x74", SubmitType::class, ["\x61\x74\x74\162" => ["\x63\x6c\141\x73\163" => "\x62\x74\156\x20\142\164\156\x2d\154\147\x20\x62\164\x6e\55\x62\x6c\x75\145"], "\154\x61\142\145\154" => "\103\162\145\x61\164\x65"]); goto fcd6a; C8eb3: $form = $this->createForm("\101\x70\160\x5c\106\x6f\162\x6d\134\x53\151\x74\x65\116\145\x77\x52\x65\x76\x65\162\163\x65\120\x72\157\x78\x79\x54\x79\x70\x65", [], ["\x61\x63\x74\151\157\156" => $this->generateUrl("\x63\154\x70\x5f\163\x69\164\145\x5f\162\145\166\145\162\x73\x65\137\x70\x72\157\x78\x79\137\x6e\x65\167"), "\155\x65\164\x68\x6f\x64" => "\120\x4f\123\124", "\141\x74\164\x72" => ["\151\x64" => "\156\x65\167\55\x72\145\x76\145\162\x73\x65\x2d\x70\x72\x6f\x78\x79\x2d\x66\x6f\x72\155"]]); goto D8981; a4d73: } private function handleReverseProxyForm(Request $request, Form $form) { goto A93bc; A2764: F97eb: goto da9bf; be67b: goto F97eb; goto e5b88; cd2f0: try { goto d14b3; Af6ea: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto e2c13; e42d2: return $response; goto adb01; Dc6e6: $eventData = ["\x73\x69\x74\145" => $domainName, "\x73\151\164\x65\x55\163\x65\x72" => $siteUser, "\162\x65\x76\145\x72\163\x65\120\x72\157\170\171\x55\162\154" => $reverseProxyUrl]; goto Af6ea; B6f76: $siteUserPassword = $form->get("\163\151\164\145\125\163\x65\162\120\x61\163\163\167\157\162\x64")->getData(); goto Bf70a; Dffa6: throw new \Exception(sprintf("\126\x68\x6f\x73\x74\x20\164\x65\x6d\160\x6c\141\164\x65\40\42\x25\163\x22\40\156\157\x74\x20\x66\157\x75\156\144\56", $vhostTemplateName)); goto c17bd; d14b3: $session = $request->getSession(); goto bbf30; f1739: $siteUser = $form->get("\163\151\164\x65\125\163\x65\162")->getData(); goto B6f76; D9c16: $user = $this->getUser(); goto e6fc6; e6fc6: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto Dc6e6; bbf30: $domainName = $form->get("\x64\x6f\155\x61\x69\156\116\x61\x6d\x65")->getData(); goto f1739; adb01: Dba68: goto A5ce4; c17bd: goto Dba68; goto cadfb; e2c13: $session->getFlashBag()->set("\163\x75\143\143\145\x73\x73", $this->translator->trans("\x52\145\166\145\162\x73\x65\x20\x50\162\x6f\x78\171\40\150\141\x73\40\142\145\145\156\x20\x63\162\x65\141\164\145\144\56")); goto E4212; E4212: $response = $this->redirect($this->generateUrl("\143\154\160\137\163\x69\164\x65\x73")); goto e42d2; Ed5a3: if (false === is_null($vhostTemplateEntity)) { goto B0a12; } goto Dffa6; cadfb: B0a12: goto D9c16; A3d0d: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto d2915; d2915: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ed5a3; Bf70a: $reverseProxyUrl = $form->get("\x72\145\x76\x65\x72\163\x65\120\162\157\170\171\x55\x72\x6c")->getData(); goto A3d0d; A5ce4: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\x67\145\x72", $this->translator->trans("\x41\x6e\40\145\x72\162\157\162\40\150\141\163\40\157\143\143\x75\162\162\145\144\x2c\40\x65\x72\x72\157\x72\40\x6d\145\163\163\141\x67\x65\x3a\x20\45\145\x72\x72\x6f\162\115\145\163\163\x61\147\x65\x25", ["\45\145\x72\x72\157\162\x4d\x65\163\163\141\x67\145\45" => $e->getMessage()])); } goto A2764; e5b88: bbb57: goto cd2f0; A93bc: if (true === $form->isValid()) { goto bbb57; } goto f2953; f2953: $this->formErrors = $this->getErrorMessages($form); goto be67b; da9bf: } public function newNodejsSite(Request $request) : Response { goto B001b; B001b: $hasPermissions = $this->hasPermissions(); goto Ca9ad; d1a60: $form->handleRequest($request); goto d8d5a; f521f: $user = $this->getUser(); goto a200c; d5a06: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\151\x74\145\163")); goto b188c; c97bf: e63ad: goto f521f; B9232: A91c3: goto fd1b4; b188c: goto A91c3; goto c97bf; fd1b4: return $response; goto a4ddf; daee2: c0777: goto da8c7; De65b: $response = $this->render("\x46\x72\157\x6e\164\145\156\144\x2f\123\x69\x74\145\57\x4e\x65\x77\x2f\x6e\157\x64\x65\x6a\x73\56\150\164\x6d\154\56\164\x77\x69\147", ["\x75\163\145\x72" => $user, "\146\x6f\162\155" => $form->createView(), "\146\x6f\162\155\x45\x72\162\x6f\162\163" => $this->formErrors]); goto B9232; D573f: if (!(true === $request->isMethod("\120\117\123\x54"))) { goto b798d; } goto d1a60; f5702: return $response; goto e6dc4; e6dc4: F6edc: goto daee2; da8c7: b798d: goto De65b; F0c30: if (!(false === is_null($response))) { goto F6edc; } goto f5702; b1f8a: $form = $this->createNodejsSiteForm($nodejsSettings); goto D573f; a200c: $nodejsSettings = new NodejsSettingsEntity(); goto b1f8a; Ca9ad: if (true === $hasPermissions) { goto e63ad; } goto d5a06; d8d5a: if (!(true === $form->isSubmitted())) { goto c0777; } goto bdde6; bdde6: $response = $this->handleCreateNodejsSiteForm($request, $form); goto F0c30; a4ddf: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto d7be7; Dd0d0: $form->add("\x73\165\142\155\x69\x74", SubmitType::class, ["\141\164\x74\162" => ["\143\x6c\x61\163\x73" => "\142\164\156\x20\142\164\156\x2d\154\147\40\142\x74\156\55\x62\154\x75\x65"], "\x6c\141\142\145\154" => "\103\x72\145\141\x74\x65"]); goto cc728; cc728: return $form; goto b16e7; d7be7: $form = $this->createForm("\x41\x70\x70\x5c\x46\157\x72\x6d\x5c\123\151\x74\145\x4e\145\167\x4e\x6f\x64\x65\152\163\x54\x79\160\145", $nodejsSettings, ["\x61\143\x74\151\x6f\x6e" => $this->generateUrl("\143\154\x70\137\x73\151\x74\145\x5f\x6e\x6f\144\145\152\163\137\156\145\x77"), "\155\x65\x74\x68\157\x64" => "\120\x4f\x53\124", "\x61\164\x74\x72" => ["\x69\144" => "\x6e\x65\167\55\156\157\144\x65\x6a\163\x2d\163\x69\x74\x65\55\x66\157\x72\x6d"]]); goto Dd0d0; b16e7: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto Cd72c; Cd72c: if (true === $form->isValid()) { goto d3e3d; } goto cb9c2; b061c: f3767: goto C6a1b; c6372: try { goto B4e99; C57f7: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto d7fc3; Eaa3a: $domainName = $form->get("\x64\x6f\x6d\x61\x69\x6e\116\x61\155\145")->getData(); goto F7d12; Cb9b5: throw new \Exception(sprintf("\126\150\157\x73\x74\x20\164\145\x6d\x70\154\x61\x74\x65\40\42\45\163\x22\40\156\157\x74\x20\x66\x6f\x75\156\x64\x2e", $vhostTemplateName)); goto B4c63; Ec77d: $siteUser = $form->get("\x73\x69\164\x65\x55\x73\145\162")->getData(); goto Fc8d2; E7516: $user = $this->getUser(); goto b20c4; C67d9: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto B947c; Be25e: $port = $form->get("\x70\x6f\x72\x74")->getData(); goto Ec77d; B4c63: goto f4891; goto E8a51; F7d12: $nodejsVersion = $form->get("\x6e\157\x64\x65\152\163\x56\x65\162\x73\151\x6f\x6e")->getData(); goto Be25e; b4bed: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\163\151\x74\145\x73")); goto A2d1b; F50b6: f4891: goto A944e; b20c4: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto a1306; Ddcbc: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto C57f7; B4e99: $session = $request->getSession(); goto Eaa3a; E8a51: d4abd: goto E7516; A2d1b: return $response; goto F50b6; Fc8d2: $siteUserPassword = $form->get("\163\x69\x74\145\x55\163\x65\162\x50\x61\x73\x73\167\x6f\x72\144")->getData(); goto Ddcbc; B947c: $session->getFlashBag()->set("\x73\165\x63\x63\145\x73\x73", $this->translator->trans("\123\x69\164\145\x20\150\x61\x73\40\142\x65\145\156\x20\143\162\145\x61\164\145\144\x2e")); goto b4bed; a1306: $eventData = ["\x73\x69\x74\x65" => $domainName, "\x73\x69\x74\x65\x55\x73\x65\x72" => $siteUser, "\x6e\x6f\x64\145\x6a\x73\x56\x65\162\x73\x69\x6f\x6e" => $nodejsVersion, "\160\157\x72\164" => $port]; goto C67d9; d7fc3: if (false === is_null($vhostTemplateEntity)) { goto d4abd; } goto Cb9b5; A944e: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\x67\x65\x72", $this->translator->trans("\101\156\x20\x65\162\162\157\x72\x20\x68\x61\163\x20\x6f\143\143\x75\x72\162\x65\144\54\x20\145\162\x72\157\162\x20\155\x65\163\163\x61\147\x65\72\40\x25\145\162\162\157\x72\115\x65\x73\x73\141\147\145\x25", ["\x25\x65\x72\x72\157\x72\x4d\145\163\163\x61\x67\x65\x25" => $e->getMessage()])); } goto b061c; cb9c2: $this->formErrors = $this->getErrorMessages($form); goto e0d1f; a74ee: d3e3d: goto c6372; e0d1f: goto f3767; goto a74ee; C6a1b: } public function newStaticSite(Request $request) : Response { goto d615e; fe80d: $response = $this->handleCreateStaticSiteForm($request, $form); goto f8f7c; de670: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\151\164\x65\163")); goto ae54d; d2691: f80ae: goto efa17; ca853: if (!(true === $request->isMethod("\x50\x4f\x53\x54"))) { goto e1a47; } goto c49b8; efa17: $user = $this->getUser(); goto bd23c; fdf8a: fc55d: goto E467f; Fe8c6: Fd181: goto Edb48; d615e: $hasPermissions = $this->hasPermissions(); goto d2f7a; ea18b: if (!(true === $form->isSubmitted())) { goto bbac7; } goto fe80d; ae54d: goto fc55d; goto d2691; Edb48: bbac7: goto adbcd; bd23c: $form = $this->createStaticSiteForm(); goto ca853; Fd046: $response = $this->render("\106\162\x6f\156\x74\145\156\x64\x2f\123\151\x74\145\x2f\116\145\167\x2f\x73\x74\x61\x74\x69\143\56\x68\164\155\154\56\x74\x77\x69\147", ["\165\x73\x65\162" => $user, "\x66\x6f\162\155" => $form->createView(), "\x66\157\162\155\105\x72\162\157\x72\163" => $this->formErrors]); goto fdf8a; c49b8: $form->handleRequest($request); goto ea18b; adbcd: e1a47: goto Fd046; E467f: return $response; goto D6c34; f8a4d: return $response; goto Fe8c6; d2f7a: if (true === $hasPermissions) { goto f80ae; } goto de670; f8f7c: if (!(false === is_null($response))) { goto Fd181; } goto f8a4d; D6c34: } private function createStaticSiteForm() : Form { goto dbaf3; dbaf3: $form = $this->createForm("\101\x70\x70\x5c\x46\157\x72\x6d\134\x53\x69\164\145\x4e\x65\x77\x53\x74\x61\x74\x69\143\124\171\160\x65", [], ["\141\x63\164\x69\x6f\156" => $this->generateUrl("\x63\x6c\160\x5f\163\151\164\x65\137\163\x74\x61\164\151\143\137\156\145\x77"), "\155\145\x74\x68\x6f\144" => "\x50\x4f\x53\124", "\141\164\x74\162" => []]); goto F31e6; dadfa: return $form; goto C4343; F31e6: $form->add("\x73\x75\x62\155\151\x74", SubmitType::class, ["\141\164\164\162" => ["\x63\154\141\x73\x73" => "\142\164\x6e\x20\x62\164\x6e\55\x6c\x67\40\142\164\156\55\142\154\x75\145"], "\x6c\x61\142\145\x6c" => "\103\162\145\141\x74\x65"]); goto dadfa; C4343: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto eb57a; eb57a: if (true === $form->isValid()) { goto C25f3; } goto e4a49; D679f: C25f3: goto fca7a; e4a49: $this->formErrors = $this->getErrorMessages($form); goto f0eb6; fca7a: try { goto E1e0d; D2f3c: $user = $this->getUser(); goto Cdfa8; B551f: $session->getFlashBag()->set("\x73\x75\x63\143\145\163\x73", $this->translator->trans("\123\151\x74\x65\x20\150\141\x73\x20\142\x65\x65\x6e\40\x63\162\145\141\164\x65\144\56")); goto e16fc; b4323: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto B551f; a6731: $eventData = ["\x73\x69\x74\145" => $domainName, "\163\x69\164\145\125\163\145\162" => $siteUser]; goto b4323; E1e0d: $session = $request->getSession(); goto dc084; dc084: $domainName = $form->get("\x64\157\x6d\141\x69\156\x4e\x61\155\145")->getData(); goto a482d; E3632: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ab9d5; a482d: $siteUser = $form->get("\x73\x69\x74\x65\125\x73\x65\162")->getData(); goto E4235; Ab9d5: if (false === is_null($vhostTemplateEntity)) { goto e5a2d; } goto f2a14; Eedeb: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto E3632; Deb73: return $response; goto Cafcb; Cdfa8: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto a6731; e16fc: $response = $this->redirect($this->generateUrl("\x63\154\160\137\163\151\x74\145\163")); goto Deb73; E4235: $siteUserPassword = $form->get("\163\151\164\x65\125\163\x65\162\x50\x61\x73\x73\167\x6f\162\x64")->getData(); goto Eedeb; Cafcb: def32: goto fd757; A3b9e: goto def32; goto abd00; f2a14: throw new \Exception(sprintf("\126\x68\157\163\164\x20\x74\145\x6d\160\x6c\x61\164\x65\40\42\x25\163\42\40\x6e\157\164\40\146\x6f\x75\x6e\144\56", $vhostTemplateName)); goto A3b9e; abd00: e5a2d: goto D2f3c; fd757: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\147\x65\162", $this->translator->trans("\101\156\40\x65\162\162\x6f\162\x20\150\x61\163\x20\157\143\x63\165\162\x72\x65\144\x2c\40\x65\x72\162\157\x72\x20\x6d\145\163\x73\141\x67\x65\x3a\x20\45\x65\x72\162\x6f\x72\x4d\x65\163\163\x61\x67\x65\45", ["\x25\x65\162\x72\x6f\162\x4d\x65\163\x73\141\x67\145\45" => $e->getMessage()])); } goto Db459; f0eb6: goto a238d; goto D679f; Db459: a238d: goto ccd4f; ccd4f: } public function newPhpSite(Request $request) : Response { goto bdda5; ef828: e48db: goto b846a; D637b: $response = $this->render("\106\x72\157\156\x74\145\x6e\x64\x2f\x53\x69\x74\x65\x2f\116\x65\167\57\160\150\160\56\150\x74\155\x6c\x2e\x74\x77\151\x67", ["\165\163\x65\162" => $user, "\146\x6f\162\x6d" => $form->createView(), "\146\157\x72\x6d\105\x72\x72\157\162\x73" => $this->formErrors]); goto fb07c; d939f: $response = $this->handleCreatePhpSiteForm($request, $form); goto ea838; fb07c: bf4ee: goto d0590; aad33: $form = $this->createPhpSiteForm(); goto De9ee; Fc5d2: if (!(true === $form->isSubmitted())) { goto e48db; } goto d939f; A6214: return $response; goto Bf092; bdda5: $hasPermissions = $this->hasPermissions(); goto Bc256; f6a72: e74a6: goto B1bad; d0590: return $response; goto C456c; Bc256: if (true === $hasPermissions) { goto e74a6; } goto c4f58; De9ee: if (!(true === $request->isMethod("\120\117\123\x54"))) { goto c9907; } goto F1f23; ea838: if (!(false === is_null($response))) { goto D03ff; } goto A6214; B1bad: $user = $this->getUser(); goto aad33; F1f23: $form->handleRequest($request); goto Fc5d2; Bf092: D03ff: goto ef828; b846a: c9907: goto D637b; E6972: goto bf4ee; goto f6a72; c4f58: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\151\x74\x65\x73")); goto E6972; C456c: } private function createPhpSiteForm() : Form { goto a25ec; c33b4: return $form; goto D9873; C2771: $form->add("\163\x75\x62\x6d\151\x74", SubmitType::class, ["\141\164\164\x72" => ["\x63\x6c\141\163\x73" => "\142\x74\156\40\142\164\x6e\55\154\x67\x20\142\x74\156\x2d\x62\154\x75\x65"], "\x6c\x61\x62\145\x6c" => "\103\162\x65\x61\x74\x65"]); goto c33b4; a25ec: $form = $this->createForm("\x41\x70\x70\x5c\x46\157\x72\x6d\x5c\x53\x69\x74\x65\116\145\167\120\150\160\x54\171\x70\145", [], ["\141\143\164\x69\x6f\x6e" => $this->generateUrl("\143\154\x70\x5f\x73\x69\x74\145\x5f\160\x68\160\x5f\x6e\x65\x77"), "\x6d\x65\164\x68\x6f\144" => "\120\x4f\x53\x54", "\x61\x74\x74\162" => []]); goto C2771; D9873: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto Ad5e5; fe3e5: B3ffc: goto d82f1; A7be4: try { goto dc9a4; Dfb17: Dbcaf: goto A2d1a; Cb411: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto B55c2; c98fb: $vhostTemplateName = $form->get("\x61\160\160\x6c\151\143\141\164\x69\x6f\x6e")->getData(); goto f2934; E1112: c07a3: goto Cb411; B55c2: $eventData = ["\x73\151\x74\x65" => $domainName, "\166\x68\x6f\163\164\x54\x65\155\x70\154\141\164\145\x4e\x61\x6d\x65" => $vhostTemplateName, "\160\150\160\126\145\162\163\151\157\x6e" => $phpVersion, "\x73\x69\x74\145\x55\x73\145\x72" => $siteUser]; goto f3608; ce52c: E5edc: goto d8425; f3608: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto b7851; b7851: $session->getFlashBag()->set("\x73\x75\x63\x63\145\163\163", $this->translator->trans("\123\151\x74\x65\x20\150\141\163\x20\142\x65\x65\x6e\x20\143\162\145\141\x74\145\x64\56")); goto A4b68; f3ca3: $siteUserPassword = $form->get("\x73\151\x74\x65\x55\163\145\162\x50\x61\163\x73\167\x6f\162\x64")->getData(); goto f0dbb; a3346: $rootDirectory = sprintf("\45\x73\x2f\x25\x73", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\57")); goto Ce340; Ce340: F35ba: goto Dc746; d8425: $user = $this->getUser(); goto F93da; A4b68: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\x69\164\145\163")); goto d6036; F93da: $rootDirectory = $domainName; goto D5c6b; d6036: return $response; goto Dfb17; b2cd7: $siteUser = $form->get("\163\x69\x74\x65\x55\x73\145\162")->getData(); goto f3ca3; B0428: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto E1112; cbe00: $phpVersion = $form->get("\x70\x68\x70\x56\145\x72\x73\151\157\x6e")->getData(); goto b2cd7; e8d16: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto c07a3; } goto B0428; Ace99: throw new \Exception(sprintf("\x56\x68\157\x73\164\40\x74\x65\155\160\x6c\141\x74\145\40\42\45\x73\42\40\156\157\x74\40\x66\x6f\165\156\x64\x2e", $vhostTemplateName)); goto A1e96; f0dbb: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto cd69b; f2934: $domainName = $form->get("\x64\x6f\155\x61\x69\x6e\x4e\141\155\x65")->getData(); goto cbe00; dc9a4: $session = $request->getSession(); goto c98fb; cd69b: if (false === is_null($vhostTemplateEntity)) { goto E5edc; } goto Ace99; Dc746: $varnishCacheSettings = []; goto e8d16; A1e96: goto Dbcaf; goto ce52c; D5c6b: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto F35ba; } goto a3346; A2d1a: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\x65\162", $this->translator->trans("\x41\x6e\40\145\x72\x72\157\x72\40\150\141\163\40\x6f\x63\x63\x75\162\x72\x65\x64\54\40\x65\162\x72\x6f\x72\40\155\145\163\163\x61\147\x65\x3a\x20\x25\x65\x72\162\x6f\162\x4d\145\x73\163\x61\x67\x65\45", ["\x25\x65\162\x72\157\162\115\x65\x73\x73\141\147\x65\x25" => $e->getMessage()])); } goto fe3e5; Ad5e5: if (true === $form->isValid()) { goto C4a36; } goto d601c; F7f76: C4a36: goto A7be4; acc98: goto B3ffc; goto F7f76; d601c: $this->formErrors = $this->getErrorMessages($form); goto acc98; d82f1: } public function newWordPressSite(Request $request) : Response { goto e99a9; B1d8f: Abe85: goto D6f4e; b54cb: return $response; goto B1d8f; ec57f: Bd9c1: goto D8125; Be3fc: $user = $this->getUser(); goto F48c9; Ebc7a: goto Bd9c1; goto ff1cd; e184e: if (true === $hasPermissions) { goto F1771; } goto A6ec1; Bcf94: efc9a: goto Abcbb; e0bb7: if (!(true === $form->isSubmitted())) { goto D94a9; } goto e54ce; F589b: if (!(false === is_null($response))) { goto Abe85; } goto b54cb; ff1cd: F1771: goto Be3fc; D6f4e: D94a9: goto Bcf94; F48c9: $form = $this->createWordPressSiteForm(); goto ee0c0; e54ce: $response = $this->handleCreateWordPressSiteForm($request, $form); goto F589b; e99a9: $hasPermissions = $this->hasPermissions(); goto e184e; A6ec1: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\151\x74\145\x73")); goto Ebc7a; ee0c0: if (!(true === $request->isMethod("\120\117\x53\x54"))) { goto efc9a; } goto c3377; Abcbb: $response = $this->render("\x46\x72\157\156\x74\x65\156\x64\57\x53\151\164\x65\57\x4e\x65\167\x2f\x77\x6f\162\x64\x70\x72\x65\163\x73\56\x68\164\x6d\154\56\x74\x77\151\147", ["\165\163\x65\162" => $user, "\146\x6f\x72\155" => $form->createView(), "\146\157\x72\155\x45\x72\x72\157\x72\163" => $this->formErrors]); goto ec57f; D8125: return $response; goto ac587; c3377: $form->handleRequest($request); goto e0bb7; ac587: } private function createWordPressSiteForm() : Form { goto Faa5d; C06f7: $form->add("\163\x75\142\x6d\151\x74", SubmitType::class, ["\x61\164\164\x72" => ["\x63\x6c\141\163\x73" => "\142\164\156\40\142\x74\156\x2d\154\147\x20\142\x74\156\55\142\x6c\165\x65"], "\154\141\x62\x65\154" => "\103\162\145\x61\164\x65"]); goto d67ad; Faa5d: $form = $this->createForm("\101\x70\160\134\x46\157\162\155\x5c\x53\151\x74\x65\116\x65\167\127\x6f\162\x64\120\x72\145\x73\x73\x54\171\x70\145", [], ["\x61\x63\164\151\157\156" => $this->generateUrl("\143\154\160\137\x73\x69\x74\x65\x5f\x77\x6f\x72\144\x70\x72\145\x73\x73\137\x6e\x65\x77"), "\155\145\164\150\157\144" => "\120\x4f\123\124", "\x61\x74\x74\162" => ["\x69\x64" => "\156\145\x77\x2d\167\x6f\x72\144\x70\x72\x65\x73\163\55\x73\151\164\145\55\x66\x6f\x72\x6d"]]); goto C06f7; d67ad: return $form; goto c4490; c4490: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto f55bd; e9245: f7287: goto e555b; f55bd: if (true === $form->isValid()) { goto f7287; } goto Cf23b; Cf23b: $this->formErrors = $this->getErrorMessages($form); goto c9a32; e555b: try { goto a34fe; B0321: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto e5299; D916e: $siteCredentials[$this->translator->trans("\x44\141\164\141\142\x61\x73\145")] = [$this->translator->trans("\110\157\x73\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\120\x6f\162\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\104\141\x74\x61\142\141\163\x65\40\x4e\141\x6d\145") => $databaseName, $this->translator->trans("\104\x61\164\141\142\141\x73\145\40\x55\163\x65\x72\40\x4e\141\x6d\x65") => $databaseUserName, $this->translator->trans("\104\141\164\141\142\141\x73\145\x20\125\163\x65\x72\x20\x50\x61\163\x73\x77\x6f\162\144") => $databaseUserPassword]; goto b87ac; C38ab: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto E62fb; E65c2: $generatedName = $this->generateNameFromDomainName($domainName); goto cd718; cd718: $siteUser = $form->get("\163\151\x74\145\125\x73\x65\162")->getData(); goto edc0f; c9960: $databaseEntity->addUser($databaseUserEntity); goto D0ecc; D211d: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto D916e; Eed23: $adminPassword = $form->get("\x61\144\155\151\156\120\141\x73\163\x77\157\162\x64")->getData(); goto Aeeac; a26f5: $databaseManager->createUser($databaseUserEntity); goto d7106; Acab2: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto c20c1; F58ce: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto ea11a; aa425: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto c83a9; c20c1: D7f30: goto F58ce; F13fc: b7eb2: goto Cca4a; F5f6d: $databaseUserEntity->setUserName($databaseUserName); goto B0f1a; d84a0: $domainName = $form->get("\144\157\155\x61\x69\x6e\116\141\x6d\x65")->getData(); goto E65c2; c83a9: $varnishCacheSettings = []; goto Ffd82; e5299: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\163\151\164\x65\x5f\x77\157\x72\x64\160\162\145\x73\x73\137\x69\156\x73\x74\141\x6c\x6c\x65\144")); goto e17c2; Dc1d9: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto Bdd71; B5f10: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto E8e0a; E5b27: $instance = $request->attributes->get("\x69\156\163\164\141\156\143\145"); goto ab1d5; Cb899: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto F5f6d; Fb6f9: $databaseManager->createDatabase($databaseEntity); goto a26f5; ea11a: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E5b27; e17c2: return $response; goto b3922; dc64a: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto Fb6f9; Aeeac: $adminEmail = $form->get("\141\144\x6d\x69\x6e\105\155\x61\151\x6c")->getData(); goto D3168; d7106: $this->siteEntityManager->updateEntity($siteEntity); goto D211d; E8e0a: $databaseEntity = $this->databaseEntityManager->createEntity(); goto a981a; e0a02: if (!(false === is_null($siteEntity))) { goto b7eb2; } goto ef562; Cc077: $url = sprintf("\150\164\x74\x70\163\72\57\x2f\45\163", $siteEntity->getDomainName()); goto A7a6f; ef562: $databaseName = $this->getUniqueDatabaseName($generatedName); goto C38ab; f3bd4: $databaseEntity->setName($databaseName); goto d22bf; D97c8: $session = $request->getSession(); goto d84a0; D3168: $isMultiSite = $form->get("\155\x75\154\x74\151\123\151\x74\x65")->getData(); goto B5f10; A7a6f: $title = $form->get("\x73\x69\x74\x65\124\151\x74\154\x65")->getData(); goto bfbdb; Ffd82: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto D7f30; } goto Acab2; b87ac: $siteCredentials["\x57\x6f\x72\144\x50\x72\x65\x73\x73"] = [$this->translator->trans("\x41\x64\155\151\156\40\x45\55\x4d\x61\151\154") => $adminEmail, $this->translator->trans("\x41\x64\x6d\151\x6e\40\x55\x73\145\162\40\x4e\x61\x6d\x65") => $adminUserName, $this->translator->trans("\101\x64\x6d\x69\x6e\40\120\141\x73\163\167\x6f\x72\x64") => $adminPassword, $this->translator->trans("\101\x64\155\151\x6e\x20\x55\162\x6c") => sprintf("\150\164\164\x70\163\72\x2f\x2f\x25\x73\57\167\160\55\141\144\155\x69\x6e\x2f", rtrim($domainName, "\x2f"))]; goto F13fc; a34fe: $user = $this->getUser(); goto D97c8; f4f7f: $eventData = ["\163\151\x74\145" => $domainName, "\x73\151\x74\x65\125\x73\145\x72" => $siteUser]; goto B0321; edc0f: $siteUserPassword = $form->get("\163\151\x74\x65\x55\163\145\162\x50\x61\x73\x73\x77\x6f\x72\x64")->getData(); goto Beb51; Cca4a: $session->set("\163\151\164\145\x43\162\145\144\145\x6e\x74\x69\141\154\x73", $siteCredentials); goto f4f7f; D0ecc: $siteEntity->addDatabase($databaseEntity); goto dc64a; a981a: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto f3bd4; d22bf: $databaseEntity->setSite($siteEntity); goto Cb899; ab1d5: $siteCredentials = [$this->translator->trans("\x53\x69\164\x65") => [$this->translator->trans("\x49\120\40\x41\144\x64\162\x65\x73\163") => $instance->getIpv4PublicIp(), $this->translator->trans("\104\157\155\x61\x69\156\x20\116\x61\155\x65") => sprintf("\150\x74\x74\x70\163\x3a\57\x2f\x25\163", $domainName), $this->translator->trans("\x53\151\164\145\40\125\x73\145\x72") => $siteUser, $this->translator->trans("\120\x61\163\163\x77\157\x72\x64") => $siteUserPassword]]; goto e0a02; bfbdb: $adminUserName = $form->get("\141\144\x6d\151\156\x55\x73\145\x72\x4e\x61\x6d\145")->getData(); goto Eed23; Beb51: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto aa425; E62fb: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto Cc077; B0f1a: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto Dc1d9; Bdd71: $databaseUserEntity->setDatabase($databaseEntity); goto c9960; b3922: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\x67\x65\162", $this->translator->trans("\101\156\40\145\162\x72\157\162\x20\150\x61\163\40\157\x63\x63\x75\162\162\x65\144\54\x20\145\162\162\x6f\x72\40\x6d\145\163\163\141\x67\x65\72\40\x25\145\162\x72\157\x72\115\145\163\x73\x61\147\x65\x25", ["\x25\x65\x72\x72\157\x72\x4d\x65\x73\x73\x61\147\145\x25" => $e->getMessage()])); } goto F4540; c9a32: goto D04af; goto e9245; F4540: D04af: goto Bb64e; Bb64e: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto B1eaa; F3e25: $databaseUserName = $databaseUserEntity->getUserName(); goto F2a0e; C339c: $databaseName = $databaseEntity->getName(); goto F3e25; Ec3cb: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto Caa5b; b0c7e: $this->wordPressMultiSiteConfigValues["\x44\117\115\101\x49\x4e\137\103\125\x52\122\x45\x4e\124\x5f\x53\x49\124\105"]["\x76\x61\154\165\x65"] = $siteEntity->getDomainName(); goto Fecca; Fecca: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\x6c\x75\145"], $config["\162\141\x77"]); D1fd9: } goto db00b; B1eaa: $databaseHost = sprintf("\45\163\x3a\x25\x73", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto C339c; ae99c: if (!(true === $isMultiSite)) { goto dd50b; } goto b0c7e; f3094: $wordPressInstaller->resetPermissions(); goto D7eeb; Caa5b: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto C1f44; F2a0e: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto ba38d; C3a7f: Fdc6c: goto ae99c; D1886: dd50b: goto f3094; bfdae: $wordPressInstaller->downloadAndExtractLatestVersion(); goto Ec3cb; C1f44: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\x6c\x75\x65"], $config["\x72\x61\x77"]); eba2b: } goto C3a7f; ba38d: $wordPressInstaller = new WordPressInstaller($siteEntity); goto bfdae; db00b: A3bf3: goto D1886; D7eeb: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto a7dbf; E2414: $phpSite->setPhpSettings($phpSettingsEntity); goto a3743; a7dbf: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto fdc44; f9763: $phpSite->setDomainName($domainName); goto De21a; d248c: $vhostTemplate->build(); goto C4cf9; ba9cc: $phpSiteCreator->createUser(); goto C3446; dbe17: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto A73b1; B05c7: $constraintViolationList->addAll($siteConstraints); goto a5e29; fc0ad: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto c78b6; C3446: $phpSiteCreator->createRootDirectory(); goto e2c16; cc780: b589d: goto e54bc; e4326: $siteConstraints = $this->validator->validate($siteEntity); goto b1bf9; Cbdfa: $phpSettingsEntity->setPhpVersion($phpVersion); goto df86c; b239e: $certificateEntity->setSite($siteEntity); goto D41de; fb12f: throw new \Exception(implode("\73\40", $errorMessages)); goto E1da9; D41de: $rsaKeyGenerator = new RsaKeyGenerator(); goto bd14f; D0e41: $siteEntity->setPhpSettings($phpSettingsEntity); goto Cbdfa; C271b: $defaultVarnishCacheSettings = ["\x65\x6e\x61\x62\154\x65\144" => false, "\163\x65\162\166\145\x72" => self::VARNISH_CACHE_SERVER, "\x63\141\143\x68\x65\x54\141\x67\120\x72\x65\x66\x69\x78" => substr(md5(time()), 0, 4)]; goto F12f5; De21a: $phpSite->setRegistrableDomain($registrableDomain); goto f41e2; e12f9: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\x2e\45\x73", $domainName); goto Bdf62; A73b1: $csr = $csrGenerator->generate(); goto F260f; e4ac4: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto d1944; Ed461: B4220: goto c4e2a; c05be: Cc09c: goto D5efe; efa8b: if (!(false === empty($redirectionVhostTemplate))) { goto A4ba5; } goto c84fb; c78b6: $this->siteEntityManager->updateEntity($siteEntity); goto ae28e; c2c30: if (!(true === $varnishCache)) { goto b589d; } goto F06ad; f4914: $certificateEntity->setDefaultCertificate(true); goto a1925; F5734: Bd299: goto D60bf; Ffc08: $subjectAlternativeNames[] = $registrableDomain; goto c05be; Ec8fc: $certificateEntity->setCsr($csr); goto C0fd4; F260f: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto f4914; D2546: $constraintViolationList = new ConstraintViolationList(); goto B05c7; C537b: $subjectAlternativeNames = []; goto dee46; E1da9: Dd63a: goto C8aaf; C550e: $siteEntity->setType(SiteEntity::TYPE_PHP); goto fb839; d80ec: $vhostTemplate->resetProcessors(); goto A245a; C0fd4: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto e0c2f; b7df4: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto f4d12; Cb031: A4ba5: goto Ed461; Bdf62: Ff597: goto e50a0; Deacb: $phpSite = new PhpSite(); goto c3adb; Dd393: D7932: goto a926f; b9a20: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto cd496; c4e2a: $siteEntity->setVhostTemplate($vhostTemplate); goto d45ba; d99c2: $phpSiteCreator->reloadNginxService(); goto A1ffd; a926f: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\56\x2e\57\56\56\57\162\145\163\x6f\165\162\143\145\x73\57\156\x67\151\x6e\170\x2f\x76\150\x6f\163\x74\x5f\x74\x65\x6d\160\154\141\164\145\x2f\162\145\x64\151\162\x65\143\x74\x2d\150\x74\x74\x70\63"); goto B04bb; E96ca: $siteEntity->setUserPassword($siteUserPassword); goto d1b5c; d1944: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto cfcdf; A1ffd: $phpSiteCreator->resetPermissions(); goto Eb54f; e4424: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\x2f\56\x2e\57\56\56\57\162\x65\x73\157\x75\x72\143\145\163\x2f\156\147\151\156\170\x2f\x76\150\157\x73\164\x5f\164\x65\x6d\x70\x6c\141\164\x65\x2f\x72\x65\x64\151\162\x65\x63\x74"); goto C1906; C4cf9: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto fc0ad; a3743: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto B9b52; e0c2f: $certificateEntity->setCertificate($selfSignedCertificate); goto A5b49; C1906: goto Cbb46; goto Dd393; cfcdf: $subdomain = $resolvedDomainName->subDomain()->toString(); goto b07ad; ade8b: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto f52f0; e54bc: $phpSiteCreator->createNginxVhost(); goto d99c2; a5e29: $constraintViolationList->addAll($phpSettingsConstraints); goto d382e; d42e6: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto efa8b; A307e: $siteEntity->setUser($siteUser); goto E96ca; d1b5c: $siteEntity->setRootDirectory($rootDirectory); goto F9877; F9877: if (!(false === empty($varnishCache))) { goto Bd299; } goto e3f1f; D8026: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto f9763; e2c16: $phpSiteCreator->createLogrotateFile(); goto Cc1f2; f4d12: $siteEntity = $this->siteEntityManager->createEntity(); goto C550e; c3adb: $phpSite->setUser($siteEntity->getUser()); goto D8026; f52f0: $phpSite->setCertificate($certificateEntity); goto E2414; B04bb: Cbb46: goto d42e6; d252f: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto cc780; fb839: $siteEntity->setDomainName($domainName); goto A307e; daad4: $phpSiteCreator->reloadPhpFpmService(); goto c2c30; d3e72: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto Dd63a; } goto D2546; Cc1f2: $phpSiteCreator->createIndexPhp(); goto Cc43e; ae28e: return $siteEntity; goto c5f9b; F06ad: $phpSite->setVarnishCache(true); goto C271b; D5efe: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto dbe17; bd14f: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto C537b; d45ba: $phpSettingsEntity = new PhpSettingsEntity(); goto D0e41; Cc43e: $phpSiteCreator->createPrivateKeyAndCertificate(); goto e4448; c84fb: $vhostTemplate = sprintf("\45\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto Cb031; C8aaf: $certificateEntity = $this->certificateEntityManager->createEntity(); goto b239e; A245a: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto b9a20; A7b37: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto d252f; f3556: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto b7df4; cd496: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto d248c; e50a0: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto Cc09c; } goto Ffc08; b07ad: $subdomain = false === empty($subdomain) ? $subdomain : null; goto f3556; e4448: $phpSiteCreator->createPhpFpmPool(); goto daad4; A5b49: $siteEntity->setCertificate($certificateEntity); goto Deacb; d382e: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto fb12f; fdc44: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\x2f")), "\57"); goto e4ac4; F12f5: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto A7b37; Eb54f: $vhostTemplate = new PhpVhostTemplate($phpSite); goto Ef8bd; dee46: if (!(true === is_null($subdomain))) { goto Ff597; } goto e12f9; f41e2: $phpSite->setSubdomain($subdomain); goto ade8b; a1925: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Ec8fc; B9b52: $phpSiteCreator = new PhpSiteCreator($phpSite); goto ba9cc; Ef8bd: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto d80ec; ebe73: if (true === isset($_ENV["\101\120\x50\x5f\x48\x54\124\x50\63"]) && "\x74\x72\165\x65" === $_ENV["\x41\x50\x50\137\x48\x54\x54\120\x33"]) { goto D7932; } goto e4424; df86c: $phpSettingsEntity->setSite($siteEntity); goto e4326; e3f1f: $siteEntity->setVarnishCache(true); goto F5734; D60bf: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto B4220; } goto ebe73; b1bf9: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto d3e72; c5f9b: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto da52d; f6977: if (!(false === empty($redirectionVhostTemplate))) { goto efe22; } goto E0b9d; c0b7e: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto C3a29; Eb8be: $certificateEntity->setCsr($csr); goto c2d93; c2d93: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto A20e7; b56cd: $nodejsSiteCreator->reloadNginxService(); goto Ff593; d796b: $nodejsSettingsEntity->setPort($port); goto D5a8e; A4a86: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto A0545; F4f0c: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\57\x2e\x2e\x2f\x2e\x2e\x2f\162\145\x73\157\x75\162\x63\145\x73\x2f\156\147\x69\x6e\170\x2f\166\x68\x6f\163\164\x5f\164\x65\x6d\x70\x6c\x61\x74\x65\x2f\162\145\144\x69\162\145\x63\x74\55\150\164\x74\x70\x33"); goto B422f; A20e7: $certificateEntity->setCertificate($selfSignedCertificate); goto Ce355; a6dcb: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto D7475; Ce355: $siteEntity->setCertificate($certificateEntity); goto Cdd2a; c4aba: $subjectAlternativeNames[] = $registrableDomain; goto af1d3; dd067: if (!(false === is_null($subdomain) && "\167\x77\x77" == $subdomain)) { goto E21c7; } goto c4aba; bd79e: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto d796b; ab02c: $vhostTemplate->resetProcessors(); goto e86a5; F101d: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto A8385; de498: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto ae748; Ff593: $nodejsSiteCreator->resetPermissions(); goto F3d2d; f4a58: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto D950d; ae5a4: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\56\57\56\x2e\57\162\145\163\x6f\x75\162\143\145\x73\57\156\147\x69\x6e\170\x2f\x76\150\157\163\164\x5f\164\x65\155\160\x6c\x61\x74\145\57\x72\x65\x64\x69\x72\145\143\x74"); goto Dc9a3; f919a: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F101d; be8f6: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Eb8be; D7475: $certificateEntity->setDefaultCertificate(true); goto be8f6; d274e: $nodejsSiteCreator->createRootDirectory(); goto C2f0b; B674a: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto a00c3; a0ed4: efe22: goto Aac3f; Aac3f: D4da5: goto D50e2; Ea9d5: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto e54b0; af1d3: E21c7: goto f919a; a0ad3: $nodejsSite->setRegistrableDomain($registrableDomain); goto f339e; D50e2: $siteEntity->setVhostTemplate($vhostTemplate); goto Ee3c8; Cdd2a: $nodejsSite = new NodejsSite(); goto D37ca; Eb2e2: $certificateEntity->setSite($siteEntity); goto e265d; B99a8: if (true === isset($_ENV["\x41\120\x50\x5f\x48\124\x54\120\63"]) && "\164\162\165\145" === $_ENV["\101\x50\120\137\110\x54\124\x50\x33"]) { goto b11be; } goto ae5a4; c357b: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Ea9d5; ae748: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto b7032; f134c: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto cb22a; Ef247: $subjectAlternativeNames[] = sprintf("\167\x77\167\56\45\x73", $domainName); goto Af80e; D5a8e: $nodejsSettingsEntity->setSite($siteEntity); goto D6e2c; E0b9d: $vhostTemplate = sprintf("\x25\163\45\163", $redirectionVhostTemplate, $vhostTemplate); goto a0ed4; d2e74: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto Cfc1c; D950d: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto F4e9f; a98a1: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto f4a58; D6e2c: $siteConstraints = $this->validator->validate($siteEntity); goto c0b7e; d8b2d: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto bd79e; da52d: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto A86c2; A86c2: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto b86d3; Af80e: D4f5c: goto dd067; F4e9f: $nodejsSiteCreator->createUser(); goto d274e; E6ac1: $nodejsSiteCreator->createNvmDirectory(); goto cb47d; D37ca: $nodejsSite->setUser($siteEntity->getUser()); goto d2e74; ff9fe: $siteEntity->setRootDirectory($domainName); goto D91f8; Ee675: $constraintViolationList->addAll($siteConstraints); goto F5ab3; A8385: $csr = $csrGenerator->generate(); goto a6dcb; Dc9a3: goto C9a7e; goto Ee3e2; b900c: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto e2a97; B422f: C9a7e: goto Bef0b; e2a97: $nodejsSite->setCertificate($certificateEntity); goto a98a1; cb47d: $nodejsSiteCreator->installNodejs(); goto d20ef; cb22a: $subjectAlternativeNames = []; goto b983a; d20ef: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto d78b4; a00c3: $this->siteEntityManager->updateEntity($siteEntity); goto cf0c3; b86d3: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c8ae8; Bef0b: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto f6977; D91f8: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto D4da5; } goto B99a8; E539c: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto ab02c; e54b0: $vhostTemplate->build(); goto B2888; F5ab3: $constraintViolationList->addAll($nodejsSettingsConstraints); goto A4a86; e265d: $rsaKeyGenerator = new RsaKeyGenerator(); goto f134c; f339e: $nodejsSite->setSubdomain($subdomain); goto b900c; C3a29: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto C4853; } goto d4991; A0545: throw new \Exception(implode("\73\40", $errorMessages)); goto e16f4; aba1f: $siteEntity->setUserPassword($siteUserPassword); goto ff9fe; E374b: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto f997f; d78b4: $nodejsSiteCreator->createNginxVhost(); goto b56cd; B2888: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto B674a; C2f0b: $nodejsSiteCreator->createLogrotateFile(); goto E6ac1; Ee3c8: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto d8b2d; f997f: $siteEntity->setDomainName($domainName); goto A6d4b; b7032: $siteEntity = $this->siteEntityManager->createEntity(); goto E374b; A6d4b: $siteEntity->setUser($siteUser); goto aba1f; b983a: if (!(true === is_null($subdomain))) { goto D4f5c; } goto Ef247; cf0c3: return $siteEntity; goto bf719; c8ae8: $subdomain = false === empty($subdomain) ? $subdomain : null; goto de498; Cdd4e: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Eb2e2; e16f4: C4853: goto Cdd4e; d4991: $constraintViolationList = new ConstraintViolationList(); goto Ee675; F3d2d: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto E539c; e86a5: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto c357b; Cfc1c: $nodejsSite->setDomainName($domainName); goto a0ad3; Ee3e2: b11be: goto F4f0c; bf719: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto f91c0; C95df: $rsaKeyGenerator = new RsaKeyGenerator(); goto ef1f4; F0986: throw new \Exception(implode("\73\x20", $errorMessages)); goto Ca702; Ebfcc: $vhostTemplate = sprintf("\45\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto B782e; Fb1ec: $siteEntity->setCertificate($certificateEntity); goto faa33; c3366: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto df6b1; B6762: df74a: goto Ca278; B7c5b: $siteEntity->setDomainName($domainName); goto F80be; d704a: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto F7618; b7ccb: $siteEntity->setVhostTemplate($vhostTemplate); goto b9be9; C235e: $subjectAlternativeNames[] = $registrableDomain; goto b0e44; B5a0e: $siteEntity->setPythonSettings($pythonSettingsEntity); goto Bbc08; cf926: $pythonSite->setDomainName($domainName); goto B7d59; fa5ba: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto a8bba; E44f6: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto dd0e9; b0e44: A1fb0: goto d4ead; Eed56: goto df74a; goto a8c8c; B5ac3: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto fa5ba; B7d59: $pythonSite->setRegistrableDomain($registrableDomain); goto Eac34; de7ac: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto D1eb9; ac5f9: $constraintViolationList = new ConstraintViolationList(); goto Ffea6; ea116: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto F0986; f60e0: $siteEntity->setUserPassword($siteUserPassword); goto bc926; C77f8: $this->siteEntityManager->updateEntity($siteEntity); goto E44f6; A0186: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto cf926; f77f1: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Ebf7e; ee43d: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto C77f8; C904e: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto c546a; } goto ac5f9; b9be9: $pythonSettingsEntity = new PythonSettingsEntity(); goto B5a0e; a1f2e: $pythonSite->setPythonSettings($pythonSettingsEntity); goto B5ac3; e6a43: $pythonSite->setCertificate($certificateEntity); goto a1f2e; F1090: $pythonSite->setUser($siteEntity->getUser()); goto A0186; d37d7: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\56\57\56\56\57\162\x65\x73\x6f\165\x72\x63\x65\x73\57\156\147\151\x6e\x78\57\x76\x68\x6f\163\x74\137\x74\x65\155\160\154\141\x74\145\57\x72\145\144\x69\162\x65\x63\164\55\150\164\164\160\63"); goto B6762; Fcda6: if (!(true === is_null($subdomain))) { goto Af7b3; } goto facf9; B09d9: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto B1262; Bc939: $siteEntity = $this->siteEntityManager->createEntity(); goto Fbca6; a20a1: $pythonSiteCreator->resetPermissions(); goto c3366; Ec5df: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Ec5cd; c6898: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto c32c6; dd0e9: return $siteEntity; goto F33ab; C8427: $pythonSiteCreator->reloadNginxService(); goto a20a1; eb2fe: D706f: goto b7ccb; d4ead: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto C0a05; D68e0: $pythonSiteCreator->writePythonVersionFile(); goto de7ac; fb31e: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto c47a6; Fbca6: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto B7c5b; c47a6: $certificateEntity->setCertificate($selfSignedCertificate); goto Fb1ec; B1262: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Dec6c; B782e: C8688: goto eb2fe; Ca278: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto cf503; c32c6: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f8087; Ffea6: $constraintViolationList->addAll($siteConstraints); goto E88c3; Ec5cd: $certificateEntity->setSite($siteEntity); goto C95df; f8087: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ad312; ad312: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto A0950; ef7cf: $pythonSettingsEntity->setSite($siteEntity); goto Fb9ca; C19dc: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto D706f; } goto Ef72c; Ef72c: if (true === isset($_ENV["\x41\120\120\137\x48\x54\x54\120\x33"]) && "\164\162\165\x65" === $_ENV["\x41\x50\x50\137\110\124\x54\x50\x33"]) { goto D9102; } goto db76f; F80be: $siteEntity->setUser($siteUser); goto f60e0; C0a05: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Ff49e; facf9: $subjectAlternativeNames[] = sprintf("\x77\x77\167\56\45\x73", $domainName); goto Adc2f; Ff49e: $csr = $csrGenerator->generate(); goto d704a; Ebf7e: $certificateEntity->setCsr($csr); goto fb31e; d0e33: if (!(false === is_null($subdomain) && "\167\167\167" == $subdomain)) { goto A1fb0; } goto C235e; Eac34: $pythonSite->setSubdomain($subdomain); goto c1dd4; ef1f4: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto E32f7; cf503: if (!(false === empty($redirectionVhostTemplate))) { goto C8688; } goto Ebfcc; fc0bb: $vhostTemplate->build(); goto ee43d; e9b5d: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto C904e; bc926: $siteEntity->setRootDirectory($domainName); goto C19dc; f91c0: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto c6898; D877c: $vhostTemplate->resetProcessors(); goto B09d9; Fa891: $pythonSettingsEntity->setPort($port); goto ef7cf; F7618: $certificateEntity->setDefaultCertificate(true); goto f77f1; Adc2f: Af7b3: goto d0e33; E32f7: $subjectAlternativeNames = []; goto Fcda6; D1eb9: $pythonSiteCreator->createNginxVhost(); goto C8427; a8c8c: D9102: goto d37d7; c1dd4: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto e6a43; faa33: $pythonSite = new PythonSite(); goto F1090; E88c3: $constraintViolationList->addAll($pythonSettingsConstraints); goto ea116; Ca702: c546a: goto Ec5df; A0950: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Bc939; df6b1: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto D877c; Bbc08: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto Fa891; Ec270: $pythonSiteCreator->createRootDirectory(); goto A83a4; Fb9ca: $siteConstraints = $this->validator->validate($siteEntity); goto e9b5d; a8bba: $pythonSiteCreator->createUser(); goto Ec270; db76f: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\57\x2e\x2e\x2f\x2e\x2e\57\162\145\163\x6f\x75\x72\x63\145\x73\57\x6e\147\151\156\170\x2f\x76\150\x6f\x73\x74\137\x74\x65\155\x70\x6c\x61\164\145\x2f\162\x65\x64\151\x72\145\143\x74"); goto Eed56; Dec6c: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto fc0bb; A83a4: $pythonSiteCreator->createLogrotateFile(); goto D68e0; F33ab: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto F5ca6; Ea02f: $this->siteEntityManager->updateEntity($siteEntity); goto A2130; bbd12: $staticSiteCreator->resetPermissions(); goto b788c; fc0df: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto c37af; Fcb67: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto f1cbe; Ddc06: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto Dbd83; } goto a1efe; E79d8: b0378: goto ea299; Bbeb6: $staticSiteCreator->createRootDirectory(); goto B309c; D653f: $staticSiteCreator->createUser(); goto Bbeb6; e6538: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto d5b68; Cfe1e: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Ba8a2; F4467: $rsaKeyGenerator = new RsaKeyGenerator(); goto d088d; Eca7a: $staticSiteCreator->createPrivateKeyAndCertificate(); goto b4fb0; E91eb: $siteEntity->setCertificate($certificateEntity); goto A5958; Ad675: $certificateEntity->setDefaultCertificate(true); goto b0234; Bcb72: $siteEntity->setUserPassword($siteUserPassword); goto adb49; b0234: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto fadf8; e07b6: $siteEntity->setDomainName($domainName); goto D219c; c4c56: $staticSite->setUser($siteEntity->getUser()); goto e6538; e7688: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto fc0df; Ab657: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto d2446; a0d36: $vhostTemplate = sprintf("\45\163\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto e968a; f1cbe: $vhostTemplate->resetProcessors(); goto e7688; aee67: $constraintViolationList = new ConstraintViolationList(); goto cd12c; Ff195: $csr = $csrGenerator->generate(); goto F3461; Da5d8: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Ea02f; bfbe3: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto Fba08; A5958: $staticSite = new StaticSite(); goto c4c56; d088d: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto dc56c; fb480: $subdomain = false === empty($subdomain) ? $subdomain : null; goto A37e5; Ff2e5: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto B5bf9; C3c69: $staticSite->setSubdomain($subdomain); goto Ff2e5; ea299: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\56\56\57\x2e\56\x2f\162\145\x73\x6f\x75\162\143\x65\x73\57\x6e\x67\x69\156\170\x2f\x76\x68\x6f\163\164\137\x74\x65\x6d\160\154\141\x74\x65\x2f\162\145\144\151\162\145\143\164\x2d\150\x74\164\x70\x33"); goto f0cfd; B617c: $siteConstraints = $this->validator->validate($siteEntity); goto e91ae; F9673: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Dfffb; Ed23d: $staticSite->setRegistrableDomain($registrableDomain); goto C3c69; baf1d: $siteEntity->setVhostTemplate($vhostTemplate); goto B617c; c37af: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto d662e; b788c: $vhostTemplate = new StaticVhostTemplate($staticSite); goto Fcb67; A1945: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\x2e\x2e\x2f\56\56\57\162\x65\x73\157\165\x72\143\x65\163\x2f\x6e\147\151\156\x78\57\166\x68\157\x73\x74\137\164\x65\x6d\x70\154\141\164\x65\57\x72\145\144\151\162\x65\x63\x74"); goto c9265; D56f1: e6f3c: goto Ab657; d1557: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto bfbe3; Cb936: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto e07b6; d0867: $certificateEntity = $this->certificateEntityManager->createEntity(); goto d1321; Dd09d: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Ce02a; B82de: e997c: goto c5b68; ed85e: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto a22ad; Dfffb: $certificateEntity->setCertificate($selfSignedCertificate); goto E91eb; c9265: goto A6195; goto E79d8; A37e5: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto ed85e; Ce02a: $subdomain = $resolvedDomainName->subDomain()->toString(); goto fb480; c5b68: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto e6f3c; } goto Fec95; d5b68: $staticSite->setDomainName($domainName); goto Ed23d; c913a: $subjectAlternativeNames[] = sprintf("\167\167\x77\56\x25\163", $domainName); goto B82de; dc56c: $subjectAlternativeNames = []; goto C09f9; f0cfd: A6195: goto C4ea6; b4fb0: $staticSiteCreator->createNginxVhost(); goto ee139; Ba8a2: $staticSiteCreator = new StaticSiteCreator($staticSite); goto D653f; B309c: $staticSiteCreator->createLogrotateFile(); goto B19de; Fba08: d7039: goto d0867; e968a: ae924: goto c5390; adb49: $siteEntity->setRootDirectory($domainName); goto Ddc06; F5ca6: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Dd09d; Fec95: $subjectAlternativeNames[] = $registrableDomain; goto D56f1; A2130: return $siteEntity; goto e51c0; fadf8: $certificateEntity->setCsr($csr); goto F9673; F3461: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Ad675; d662e: $vhostTemplate->build(); goto C85da; C4ea6: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto a592b; a592b: if (!(false === empty($redirectionVhostTemplate))) { goto ae924; } goto a0d36; d2446: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Ff195; ee139: $staticSiteCreator->reloadNginxService(); goto bbd12; cd12c: $constraintViolationList->addAll($siteConstraints); goto d1557; B19de: $staticSiteCreator->createIndexHtml(); goto Eca7a; d1321: $certificateEntity->setSite($siteEntity); goto F4467; c5390: Dbd83: goto baf1d; D219c: $siteEntity->setUser($siteUser); goto Bcb72; C09f9: if (!(true === is_null($subdomain))) { goto e997c; } goto c913a; C85da: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Da5d8; a1efe: if (true === isset($_ENV["\x41\120\120\x5f\x48\x54\124\x50\x33"]) && "\x74\162\x75\x65" === $_ENV["\101\x50\120\x5f\110\124\124\120\63"]) { goto b0378; } goto A1945; B5bf9: $staticSite->setCertificate($certificateEntity); goto Cfe1e; a22ad: $siteEntity = $this->siteEntityManager->createEntity(); goto Cb936; e91ae: if (!count($siteConstraints)) { goto d7039; } goto aee67; e51c0: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto Eefa8; D314b: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto E5e14; f845a: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Bba6e; Ab308: goto Fe0b4; goto dc348; ab565: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto Ce0a7; B9d6d: $vhostTemplate->build(); goto aec08; b2c04: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto Caf23; e0060: $reverseProxySite->setRegistrableDomain($registrableDomain); goto a151b; A3d55: $certificateEntity->setCertificate($selfSignedCertificate); goto A6931; e1046: throw new \Exception(implode("\x3b\40", $errorMessages)); goto bda4d; E99c9: $siteEntity->setUser($siteUser); goto C1ed2; ce66a: $certificateEntity->setSite($siteEntity); goto c3d1f; b3ae9: F5c31: goto f604e; cde4b: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto a5380; F4f0e: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto A3d55; c7e63: $subjectAlternativeNames[] = sprintf("\167\167\167\56\x25\x73", $domainName); goto Df561; cf5a4: if (true === isset($_ENV["\101\x50\120\137\110\x54\x54\120\63"]) && "\x74\162\165\145" === $_ENV["\101\x50\120\137\x48\x54\x54\120\x33"]) { goto df740; } goto daadf; cf6e6: $csr = $csrGenerator->generate(); goto b96dc; Df561: Ab2d0: goto cb792; f55cd: $reverseProxySite->setUser($siteEntity->getUser()); goto D7142; c4870: $subjectAlternativeNames[] = $registrableDomain; goto b3ae9; a151b: $reverseProxySite->setSubdomain($subdomain); goto Eebce; D370d: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto E7baa; b7093: A3aea: goto A513b; F2a73: $subjectAlternativeNames = []; goto B3017; cf889: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto f845a; bfdf3: $reversProxySiteCreator->createLogrotateFile(); goto a4d11; aec08: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Ba97d; c0813: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\56\x2f\x2e\56\57\162\145\163\157\x75\162\143\x65\x73\57\x6e\x67\151\x6e\x78\57\166\150\157\163\x74\x5f\164\x65\x6d\160\x6c\x61\x74\x65\57\162\145\x64\151\x72\x65\x63\x74\x2d\x68\x74\164\x70\x33"); goto bb814; eb99d: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto B9d6d; cb792: if (!(false === is_null($subdomain) && "\167\x77\167" == $subdomain)) { goto F5c31; } goto c4870; f5461: $reversProxySiteCreator->resetPermissions(); goto e4e60; F3477: $certificateEntity->setCsr($csr); goto F4f0e; E7baa: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto eb99d; c2939: $reverseProxySite->setCertificate($certificateEntity); goto cf889; A2d03: if (!(false === empty($redirectionVhostTemplate))) { goto A3aea; } goto Fe8e4; D4056: $reversProxySiteCreator->createNginxVhost(); goto acb87; e526c: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Fa819; Eb2db: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto e526c; dc348: df740: goto c0813; Eebce: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto c2939; b88e3: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto e1046; A6931: $siteEntity->setCertificate($certificateEntity); goto B9c8f; bb814: Fe0b4: goto c9dbc; D92db: $siteConstraints = $this->validator->validate($siteEntity); goto f534d; C1ed2: $siteEntity->setUserPassword($siteUserPassword); goto ee0f5; f4ee7: return $siteEntity; goto F6320; daadf: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\56\x2e\57\x2e\56\x2f\x72\x65\x73\x6f\165\162\x63\x65\x73\x2f\x6e\147\151\156\170\x2f\166\x68\157\x73\x74\137\164\145\x6d\x70\154\141\164\x65\57\x72\145\144\x69\162\x65\143\x74"); goto Ab308; fdd3f: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto F2a73; B9c8f: $reverseProxySite = new ReverseProxySite(); goto f55cd; B3017: if (!(true === is_null($subdomain))) { goto Ab2d0; } goto c7e63; E5e14: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto ecbc5; bda4d: Bb0af: goto c154c; Ce0a7: $siteEntity->setDomainName($domainName); goto E99c9; Bba6e: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto Ac0f7; E961e: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto F3477; a4d11: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto D4056; ee0f5: $siteEntity->setRootDirectory($domainName); goto b2c04; e83e9: $constraintViolationList->addAll($siteConstraints); goto b88e3; Fe8e4: $vhostTemplate = sprintf("\x25\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto b7093; D7142: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto Ffc71; Be5f7: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto cf6e6; a5380: $vhostTemplate->resetProcessors(); goto D370d; e4e60: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto cde4b; Fa819: $subdomain = false === empty($subdomain) ? $subdomain : null; goto D314b; B2b96: $constraintViolationList = new ConstraintViolationList(); goto e83e9; Ffc71: $reverseProxySite->setDomainName($domainName); goto e0060; Caf23: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto ff055; } goto cf5a4; A30f3: $certificateEntity->setDefaultCertificate(true); goto E961e; Ba97d: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto ccabc; ecbc5: $siteEntity = $this->siteEntityManager->createEntity(); goto ab565; b96dc: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto A30f3; A513b: ff055: goto a8db4; c3d1f: $rsaKeyGenerator = new RsaKeyGenerator(); goto fdd3f; a8db4: $siteEntity->setVhostTemplate($vhostTemplate); goto D92db; ccabc: $this->siteEntityManager->updateEntity($siteEntity); goto f4ee7; c154c: $certificateEntity = $this->certificateEntityManager->createEntity(); goto ce66a; c9dbc: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto A2d03; Ac0f7: $reversProxySiteCreator->createUser(); goto D7820; acb87: $reversProxySiteCreator->reloadNginxService(); goto f5461; f534d: if (!count($siteConstraints)) { goto Bb0af; } goto B2b96; Eefa8: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Eb2db; f604e: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Be5f7; D7820: $reversProxySiteCreator->createRootDirectory(); goto bfdf3; F6320: } public function installedWordPressSite(Request $request) : Response { goto Bae28; bbf0c: return $response; goto c8f8f; a99af: $siteCredentials = $session->get("\163\x69\x74\x65\x43\x72\x65\144\145\156\x74\x69\141\154\x73"); goto A3f41; E6ad5: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\x73\x69\164\x65\163")); goto F2561; A3f41: if (false === empty($siteCredentials)) { goto B814a; } goto E6ad5; C347d: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto bb22e; D9eda: b10e4: goto bbf0c; Cca31: return $response; goto D9eda; Bae28: $session = $request->getSession(); goto a99af; bb22e: $response = $this->render("\x46\162\x6f\156\x74\x65\156\144\57\x53\x69\164\x65\x2f\116\145\x77\x2f\x77\x6f\162\144\x70\162\x65\x73\163\55\151\156\x73\x74\x61\x6c\154\x65\x64\56\x68\x74\x6d\x6c\x2e\164\x77\x69\x67", ["\163\x69\164\145\103\162\x65\144\x65\156\x74\151\141\x6c\x73" => $siteCredentials]); goto Cca31; F6ee2: B814a: goto C347d; F2561: goto b10e4; goto F6ee2; c8f8f: } private function renderSiteCredentials(array $siteCredentials) : string { goto Ec8c9; Ec8c9: $renderedCredentials = ''; goto Aef24; D50af: e02bd: goto D7f83; D7f83: return $renderedCredentials; goto a66ca; Aef24: foreach ($siteCredentials as $section => $sectionData) { goto cb8ab; cb8ab: $renderedCredentials .= $section . PHP_EOL; goto E3e52; d499c: bf596: goto f2b0c; E3e52: $renderedCredentials .= "\x2d\x2d\x2d\x2d\x2d\x2d\55\x2d\x2d\55\x2d\x2d\55\55\55\x2d\55\55\x2d\55\55\55\55\x2d\55\55\55\55\55\x2d\55\x2d\x2d\55\55\x2d\55\x2d\55\x2d\55\55\55\55\x2d\55\55\x2d\55\x2d\x2d\x2d\x2d\55" . PHP_EOL; goto D7ea1; D7ea1: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\163\72\40\x25\163", $key, $value) . PHP_EOL; c49da: } goto d499c; f2b0c: $renderedCredentials .= PHP_EOL; goto Ccba0; Ccba0: A429d: goto A3267; A3267: } goto D50af; a66ca: } private function getVhostTemplateEntity(string $name) : mixed { goto db3af; df575: A4311: goto Bbce8; E8146: throw new \Exception($this->translator->trans("\126\150\157\x73\164\x20\124\x65\x6d\160\154\141\164\145\40\45\x76\150\157\x73\x74\124\x65\155\160\x6c\141\164\145\x25\40\144\x6f\145\x73\40\x6e\157\x74\x20\145\170\x69\x73\164\x2e", ["\45\x76\150\x6f\x73\164\x54\x65\x6d\160\x6c\141\x74\145\x25" => $name])); goto df575; e55cf: if (!(true === is_null($vhostTemplateEntity))) { goto A4311; } goto E8146; Bbce8: return $vhostTemplateEntity; goto C73bf; db3af: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto e55cf; C73bf: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto Aed25; Aed25: $errorMessages = []; goto d491d; F0da1: return $errorMessages; goto C6388; d491d: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\163\x3a\40\45\163", $constraint->getPropertyPath(), $constraint->getMessage()); F0dc2: } goto b9802; b9802: C88f1: goto F0da1; C6388: } private function generateNameFromDomainName(string $domainName) : string { goto cc468; cfae3: $name = $explodedRegistrableDomain[0] ?? ''; goto Fce6f; D9710: $subdomain = $resolvedDomainName->subDomain()->toString(); goto E5be9; cc468: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Ff423; Ff423: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto D9710; f550f: goto dcb0a; goto b78e1; E5be9: $explodedRegistrableDomain = explode("\x2e", $registrableDomain); goto d6408; D310d: $name = sprintf("\x25\x73\55\45\163", $explodedRegistrableDomain[0] ?? '', implode("\x2d", $explodedSubdomain)); goto C4ba9; C4ba9: Bd0f7: goto f550f; f6f2b: return $name; goto A4da0; Fce6f: dcb0a: goto f6f2b; Dee11: if (!(false === empty($subdomain))) { goto Bd0f7; } goto e99b7; d51c1: $name = $explodedRegistrableDomain[0] ?? ''; goto Dee11; b78e1: Aed6c: goto cfae3; e99b7: $explodedSubdomain = explode("\x2e", $subdomain); goto D310d; d6408: if ("\167\167\167" == $subdomain) { goto Aed6c; } goto d51c1; A4da0: } private function getUniqueDatabaseName(string $databaseName) : string { goto B7f29; e5c6a: $i++; goto B2beb; A3ca1: f94e7: goto Bd4ef; B7f29: $uniqueDatabaseName = $databaseName; goto ac93f; Bb35d: $uniqueDatabaseName = sprintf("\x25\163\55\45\163", $databaseName, $i); goto E5ebe; ac93f: if (!(strlen($uniqueDatabaseName) <= 3)) { goto e1646; } goto C342e; Cd5a4: C8330: goto abed7; C342e: $uniqueDatabaseName = sprintf("\45\x73\x2d\x64\142", $uniqueDatabaseName); goto a903c; e815e: $databases = $databaseConnection->getDatabases(); goto A3ca1; C140b: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto e815e; a903c: e1646: goto e360f; f40c0: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto C140b; e360f: $i = 0; goto f40c0; Bd4ef: if (!(0 < $i)) { goto c52a0; } goto Bb35d; B2beb: if (true === $databaseExists) { goto f94e7; } goto Cd5a4; E5ebe: c52a0: goto Fb7c0; abed7: return $uniqueDatabaseName; goto bb5c2; Fb7c0: $databaseExists = in_array($uniqueDatabaseName, $databases); goto e5c6a; bb5c2: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto F0a52; c3d5f: D71fc: goto A04a4; C2786: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto e6fd2; b2786: $uniqueDatabaseUserName = sprintf("\45\x73\55\x25\163", $databaseUserName, $i); goto e7341; A04a4: $i = 0; goto ffa2e; ffa2e: Ae019: goto ff20c; e7341: F4cc2: goto C2786; Faf83: return $uniqueDatabaseUserName; goto df76f; Fcfd8: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto Faf83; F0a52: $uniqueDatabaseUserName = $databaseUserName; goto C254c; ff20c: if (!(0 < $i)) { goto F4cc2; } goto b2786; e6fd2: $i++; goto C5b7f; Dc183: $uniqueDatabaseUserName = sprintf("\45\163\x2d\x64\x62", $uniqueDatabaseUserName); goto c3d5f; d5e45: d4f21: goto Fcfd8; C254c: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto D71fc; } goto Dc183; C5b7f: if (false === is_null($databaseUserEntity)) { goto Ae019; } goto d5e45; df76f: } private function hasPermissions() : bool { goto ce6a0; b74a8: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto acb14; } goto F2107; df20a: acb14: goto ba3ee; ba3ee: return false; goto E8263; F2107: return true; goto df20a; ce6a0: $user = $this->getUser(); goto b74a8; E8263: } }
